@@ -1,10 +1,10 @@
 from callback import callback_manager
 from base import CallbackException, CallbackBase
-from signals import stored_callback, processed_callback
+from signals import stored_callback, processed_callback, error_callback
 
 
-__version__ = '0.3'
+__version__ = '0.4'
 __all__ = [
     'CallbackException', 'CallbackBase', 'callback_manager',
-    'stored_callback', 'processed_callback',
+    'stored_callback', 'processed_callback', 'error_callback',
 ]
